Module: MyTime

Included in:
Paragraph
Defined in:
lib/docfolio/paragraph.rb

Overview

Returns the new times_and_dates array for use going forwards

Returns:

  • (Array)

    returns the new times_and_dates array for use going forwards

Defined Under Namespace

Classes: TimeProcesser

Instance Method Summary collapse

Instance Method Details

#process_times(time_array, times_and_dates) ⇒ Object

Takes class start end times and dates as Time objects and amends the times, advancing the date if the start time has crossed midnight.

Parameters:

  • times_and_dates (Array)

    An array containing the Paragraph class instance variables for the start time, end time and date (day)

  • time_array (Array)

    An array containing the from hour, from min, to hour, to min



85
86
87
# File 'lib/docfolio/paragraph.rb', line 85

def process_times(time_array, times_and_dates)
  TimeProcesser.new.process_times(time_array, times_and_dates)
end